@@ -6,6 +6,8 @@ var credits =
                               ],
         [ "Christian Aigner", "Misc > Draw > Dovetail from 2 Points<br>"
                               ],
+        [ "CVH",              "Misc > Script Examples > Mathematics > FlexPainter<br>"
+                              ],
         [ "Matfie",           "Gear generator library item \"InvoluteSpur\"<br>"
                               ],
         [ "Matthias Melcher", "Drawing box joint lines<br>" +
@@ -34,6 +36,7 @@ var credits =
                               "Snap > Distance Manual<br>" +
                               "Misc > Draw > Centerline Cross<br>" +
                               "Misc > Draw > Counter<br>" +
+                              "Misc > Draw > Text Along<br>" +
                               "Misc > Development > Run Script<br>" +
                               "<i>Significant contributions to:</i><br>" +
                               "Draw > Line > Line from 2 Points<br>" +
@@ -41,25 +44,60 @@ var credits =
                               "Info > Arc/Circle/Ellipse Area<br>" +
                               "Custom linetype support, loading .lin files<br>"
                               ],
+        [ "Stephen Casner",   "Misc > Select > By Color"
+                              ],
         [ "Tamas Tevesz",     "Port to FreeBSD<br>" +
                               "Various improvements and fixes<br>"
                               ],
-        [ "Weston Schmidt",   "Draw > Dimension > Per-dimension scaling<br>"
+        [ "Weston Schmidt",   "Draw > Dimension > Per-dimension scaling<br>" +
+                              "Script inclusion path improvements<br>"
                               ],
     ],
+    [
+        qsTr("Hatch Patterns"),
+        [ "John Hyslop",         "AR-CONC-01, " +
+                                 "BARBWIRE, " +
+                                 "BLOCKS-01, BLOCKS-01, " +
+                                 "BOXJOIN-01, BOXJOIN-02, " +
+                                 "BOX-OVERLAP, " +
+                                 "BUBBLES-01, BUBBLES-02, BUBBLES-03, " +
+                                 "CELTIC-01, CELTIC-02, CELTIC-03, CELTIC-04, " +
+                                 "CIRCLES, CIRCLES-02, " +
+                                 "EXPLOSION, " +
+                                 "GRAVEL-01, " +
+                                 "HATCH-DOTS, HATCH-SQRS, " +
+                                 "HEXAGONS, " +
+                                 "HEXJOIN-01, HEXJOIN-02, " +
+                                 "HOLLY, " +
+                                 "LATTICE-01, LATTICE-02, LATTICE-03, " +
+                                 "LATTICE-04, LATTICE-05, LATTICE-06, LATTICE-07, " +
+                                 "LEAF-01, LEAF-02, LEAF-03, " +
+                                 "LOOPLINKS, " +
+                                 "MAZE-01, MAZE-02, " +
+                                 "QCAD-LOGO, " +
+                                 "REDBACK, " +
+                                 "SCAFFOLD, " +
+                                 "SQUIGGLE-01, SQUIGGLE-02, " +
+                                 "TRI-OVERLAP, " +
+                                 "WEATHERBOARD, WEAVING, " +
+                                 "WIRE-FENCE, " +
+                                 "XMASTREE-01, XMASTREE-02"
+                                 ],
+    ],
     [
         qsTr("Translations"),
-        //[ "Wang Zhen Zhe",     "Chinese (zh_CN) translation." ],
-        [ "Petr Zgraja",       "Czech (cs) translation" ],
-        [ "Andrew Mustun",     "Dutch (nl) translation" ],
-        [ "Timo Seppola",      "Finnish (fi) translation" ],
-        [ "Andrew Mustun",     "German (de) translation" ],
-        [ "Fabrizio Margini",  "Italian (it) translation" ],
-        [ "Tanaka Hidemune",   "Japanese (ja) translation and user reference manual" ],
-        [ "Евгений, AlexL",    "Russian (ru) translation" ],
-        [ "Ján Jamriška",      "Slovak (sk) translation" ],
-        [ "Miha ('miharix')",  "Slovenian (sl) translation" ],
-        [ "Eduardo Passeto",   "Portuguese (pt) translation" ],
+        [ "Petr Zgraja, 'fialot'", "Czech (cs) translation" ],
+        [ "Andrew Mustun",       "Dutch (nl) translation" ],
+        [ "Timo Seppola, Jarmo", "Finnish (fi) translation" ],
+        [ "Andrew Mustun",       "German (de) translation" ],
+        [ "Fabrizio Margini",    "Italian (it) translation" ],
+        [ "Tanaka Hidemune",     "Japanese (ja) translation and Japanese user reference manual" ],
+        [ "Евгений, AlexL",      "Russian (ru) translation" ],
+        [ "Ján Jamriška",        "Slovak (sk) translation" ],
+        [ "Miha ('miharix')",    "Slovenian (sl) translation" ],
+        [ "oltulu",              "Turkish (tr) translation" ],
+        [ "Piotr Sokół",         "Polish (pl) translation" ],
+        [ "Eduardo Passeto",     "Portuguese (pt) translation" ],
     ],
     [
         qsTr("Templates"),
